package com.ruoyi.zongzhi.service.impl;

import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.zongzhi.mapper.TcTbMapper;
import com.ruoyi.zongzhi.domain.TcTb;
import com.ruoyi.zongzhi.service.ITcTbService;

/**
 * 通报Service业务层处理
 * 
 * @author ruoyi
 * @date 2023-08-16
 */
@Service
public class TcTbServiceImpl implements ITcTbService 
{
    @Autowired
    private TcTbMapper tcTbMapper;

    /**
     * 查询通报
     * 
     * @param id 通报主键
     * @return 通报
     */
    @Override
    public TcTb selectTcTbById(Long id)
    {
        return tcTbMapper.selectTcTbById(id);
    }

    /**
     * 查询通报列表
     * 
     * @param tcTb 通报
     * @return 通报
     */
    @Override
    public List<TcTb> selectTcTbList(TcTb tcTb)
    {
        return tcTbMapper.selectTcTbList(tcTb);
    }

    /**
     * 新增通报
     * 
     * @param tcTb 通报
     * @return 结果
     */
    @Override
    public int insertTcTb(TcTb tcTb)
    {
        tcTb.setCreateTime(DateUtils.getNowDate());
        return tcTbMapper.insertTcTb(tcTb);
    }

    /**
     * 修改通报
     * 
     * @param tcTb 通报
     * @return 结果
     */
    @Override
    public int updateTcTb(TcTb tcTb)
    {
        tcTb.setUpdateTime(DateUtils.getNowDate());
        return tcTbMapper.updateTcTb(tcTb);
    }

    /**
     * 批量删除通报
     * 
     * @param ids 需要删除的通报主键
     * @return 结果
     */
    @Override
    public int deleteTcTbByIds(Long[] ids)
    {
        return tcTbMapper.deleteTcTbByIds(ids);
    }

    /**
     * 删除通报信息
     * 
     * @param id 通报主键
     * @return 结果
     */
    @Override
    public int deleteTcTbById(Long id)
    {
        return tcTbMapper.deleteTcTbById(id);
    }
}
